import React, { PropTypes } from 'react';

import FoundationButton from '../button/FoundationButton';

import FoundationLightboxAction from './FoundationLightboxAction';
import FoundationLightboxActions from './FoundationLightboxActions';
import FoundationLightboxContent from './FoundationLightboxContent';
import FoundationLightboxDescription from './FoundationLightboxDescription';
import FoundationLightboxHeader from './FoundationLightboxHeader';

import FoundationFormErrors from './error/FoundationFormErrors';

import { pgettext } from '../../utils/lang';


const FoundationLightboxBasicContent = React.createClass({

    propTypes: {
        action: PropTypes.shape({
            onClick: PropTypes.func.isRequired,
            text: PropTypes.string.isRequired,
            ui: PropTypes.string.isRequired
        }),
        children: PropTypes.node,
        description: PropTypes.string,
        errors: PropTypes.object,
        onClose: PropTypes.func,
        submitting: PropTypes.bool,
        title: PropTypes.string
    },

    getDefaultProps() {
        return {
            action: {
                onClick: () => {},
                text: pgettext('generic-action', 'Ok'),
                ui: 'primary'
            },
            description: '',
            errors: {},
            onClose: () => {},
            submitting: false,
            title: ''
        };
    },

    renderAction() {
        const { action, submitting } = this.props;
        if (action === null) {
            return null;
        }

        const { onClick, text, ui } = action;
        return (
            <FoundationLightboxAction>
                <FoundationButton
                    loading={ submitting }
                    onClick={ onClick }
                    ui={ [ui, 'mobile-stretched'] }>
                    { text }
                </FoundationButton>
            </FoundationLightboxAction>
        );
    },

    renderClose() {
        const { action, onClose, submitting } = this.props;
        return (
            <FoundationLightboxAction>
                <FoundationButton
                    disabled={ submitting }
                    onClick={ onClose }
                    ui={ ['mobile-stretched'] }>
                    { pgettext('generic-action', action !== null ? 'Cancel' : 'Close') }
                </FoundationButton>
            </FoundationLightboxAction>
        );
    },

    render() {
        const { children, description, errors, title } = this.props;
        return (
            <FoundationLightboxContent>
                <FoundationLightboxHeader>
                    { title }
                </FoundationLightboxHeader>
                <FoundationLightboxDescription>
                    { description }
                </FoundationLightboxDescription>
                { children }
                <FoundationFormErrors
                    errors={ errors } />
                <FoundationLightboxActions>
                    { this.renderAction() }
                    { this.renderClose() }
                </FoundationLightboxActions>
            </FoundationLightboxContent>
        );
    }

});

export default FoundationLightboxBasicContent;
