import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { connect } from 'react-redux';
import purebem from 'purebem';

import FoundationMobileErrorList from './FoundationMobileErrorList';

import { pgettext } from '../../../utils/lang';

import './FoundationFormErrorSection.less';


const block = purebem.of('foundation-form-error-section');

const FoundationFormErrorSection = React.createClass({

    mixins: [PureRenderMixin],

    propTypes: {
        context: PropTypes.string.isRequired,
        errors: PropTypes.array.isRequired,
        getErrorsFromState: PropTypes.func.isRequired,
        // ---
        formatKey: PropTypes.func,
        includeSeparator: PropTypes.bool
    },

    getDefaultProps() {
        return {
            includeSeparator: true
        };
    },

    render() {
        if (this.props.errors.length === 0) {
            return null;
        }

        return (
            <div className={ block() }>
                <FoundationMobileErrorList errors={ this.props.errors } />
                <hr className={ block('separator', { hidden: !this.props.includeSeparator }) } />
            </div>
        );
    }

});

const defaultFormatKey = (context, curr) => {
    return `${pgettext(context, curr)}`;
};

const mapStateToProps = (state, props) => {
    const errors = props.getErrorsFromState(state);
    const formatKey = props.formatKey || defaultFormatKey;

    return {
        errors: Object.keys(errors).reduce((prev, curr) => {
            const result = errors[curr].map((item) => {
                return `${formatKey(props.context, curr)}: ${pgettext(item[0], item[1])}`;
            });
            return [...prev, ...result];
        }, [])
    };
};

export default connect(mapStateToProps)(FoundationFormErrorSection);
