import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import isNullOrEmpty from '../../utils/isNullOrEmpty';
import toNumber from './utils/toNumber';


export default ({
    block,
    displayName
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            disabled: PropTypes.bool,
            error: PropTypes.bool,
            focus: PropTypes.bool,
            maxLength: PropTypes.string,
            name: PropTypes.string,
            onChange: PropTypes.func,
            placeholder: PropTypes.string,
            type: PropTypes.oneOf([
                'float',
                'integer',
                'integer-positive-only',
                'password',
                'text'
            ]),
            value: PropTypes.string
        },

        getDefaultProps() {
            return {
                disabled: false,
                error: false,
                focus: false,
                name: null,
                onChange: (/* { rawValue, value } */) => {},
                placeholder: null,
                type: 'text',
                value: ''
            };
        },

        componentDidMount() {
            this.focus();
        },

        componentDidUpdate() {
            this.focus();
        },

        onChange(evt) {
            const { onChange, type } = this.props;

            const rawValue = evt.target.value;
            const { value, valid } = type === 'float' || type === 'integer' || type === 'integer-positive-only'
                ? toNumber(rawValue, type)
                : { value: rawValue, valid: true };

            if (valid) {
                onChange({ rawValue, value });
            }
        },

        focus() {
            if (this.props.focus) {
                this.input.focus();
                this.input.select();
            }
        },

        render() {
            const { disabled, error, maxLength, name, placeholder, type, value } = this.props;
            return (
                <input
                    className={ block({ disabled, error }) }
                    disabled={ disabled }
                    maxLength={ maxLength }
                    name={ name }
                    onChange={ this.onChange }
                    placeholder={ placeholder }
                    ref={ (c) => this.input = c }
                    type={ type === 'password' ? 'password' : 'text' }
                    value={ value } />
            );
        }

    });

};
